#ifndef _X11_OCP
#define _X11_OCP 1

extern int x11_init(void);
extern void x11_done(void);

#endif
